[gimp] Issue #7837: gimp_installation_directory() in macOS doesn't know about…
- From: Jehan <jehanp src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] Issue #7837: gimp_installation_directory() in macOS doesn't know about…
- Date: Wed, 9 Feb 2022 11:49:06 +0000 (UTC)
commit bcdb1cdb6a99d533d677c529f466217ab3604111
Author: Jehan <jehan girinstud io>
Date: Wed Feb 9 12:47:37 2022 +0100
Issue #7837: gimp_installation_directory() in macOS doesn't know about…
… extensions yet.
libgimpbase/gimpenv.c | 7 +++++--
1 file changed, 5 insertions(+), 2 deletions(-)
---
diff --git a/libgimpbase/gimpenv.c b/libgimpbase/gimpenv.c
index 6a2ef9a8a5..00e16bf7b9 100644
--- a/libgimpbase/gimpenv.c
+++ b/libgimpbase/gimpenv.c
@@ -424,9 +424,12 @@ gimp_installation_directory (void)
toplevel = g_strdup (basepath);
}
- else if (! strcmp (dirname, "plug-ins"))
+ else if (! strcmp (dirname, "plug-ins") ||
+ ! strcmp (dirname, "extensions"))
{
/* same for plug-ins in subdirectory, go three levels up from prefix/lib/gimp/x.y */
gchar *tmp = g_path_get_dirname (basepath);
gchar *tmp2 = g_path_get_dirname (tmp);
[
@@ -424,9 +424,12 @@ gimp_installation_directory (void)
{
- /* same for plug-ins in subdirectory, go three levels up from prefix/lib/gimp/x.y */
+ /* same for plug-ins and extensions in subdirectory, go three
+ * levels up from prefix/lib/gimp/x.y
+ */
gchar *tmp = g_path_get_dirname (basepath);
gchar *tmp2 = g_path_get_dirname (tmp);
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]